=== modified file 'NEWS'
--- NEWS	2009-06-03 23:42:04 +0000
+++ NEWS	2009-06-17 22:33:55 +0000
@@ -117,11 +117,20 @@
 
     - Fix 'bzr serve --http' errors. (Matt Nordhoff, #377551)
 
+    - Added the option to hide branches by setting http_serve = False
+      in locations.conf (Martin Albisetti)
+
     - Fix serving branches over HTTP. (Matt Nordhoff, Jelmer Vernooij,
       #380026)
 
     - Install loggerhead as a bzr plugin by default (Jelmer Vernooij)
 
+    - Fix logging 404 Not Found responses (Matt Nordhoff, #381029)
+
+    - Bumped minimunm bzrlib version to 1.13 (Martin Albisetti)
+
+    - Make sure the Atom feeds (nearly) validate. (Matt Nordhoff, #247162)
+
     - Support serving branches over HTTP using the smart server protocol. 
       (Jelmer Vernooij, #306853)
 

=== renamed file 'README.txt' => 'README'
--- README.txt	2009-03-17 22:31:42 +0000
+++ README	2009-05-27 12:52:49 +0000
@@ -1,7 +1,7 @@
 LOGGERHEAD
 ==========
 
-[ Version 1.6 for Bazaar 1.6 ]
+[ Version 1.10 for Bazaar 1.6 ]
 
 Loggerhead is a web viewer for Bazaar branches.  It can be used to
 navigate a branch history, annotate files, perform searches... all the
@@ -63,31 +63,14 @@
 USING A CONFIG FILE
 -------------------
 
-Previous versions of Loggerhead read their configuration from a config
-file.  This mode of operation is still supported by the
-'start-loggerhead' script.  A 'loggerhead.conf.example' file is
-included in the source which has comments explaining the various
-options.
-
-Loggerhead can then be started by running::
-
-    $ ./start-loggerhead
-
-This will run loggerhead in the background, listening on port 8080 by
-default.
-
-To stop Loggerhead, run::
-
-    $ ./stop-loggerhead
-
-In the configuration file you can configure projects, and branches per
-project.  The idea is that you could be publishing several (possibly
-unrelated) projects through the same loggerhead instance, and several
-branches for the same project.  See the "loggerhead.conf.example" file
-included with the source.
-
-A debug and access log are stored in the logs/ folder, relative to
-the location of the start-loggerhead script.
+To hide branches from being displayed, add to ``~/.bazaar/locations.conf``,
+under the branch's section:
+
+    [/path/to/branch]
+    http_serve = False
+
+
+More configuration options to come soon.
 
 
 SERVING LOGGERHEAD FROM BEHIND APACHE
@@ -107,13 +90,14 @@
 run behind a proxy at the root of a site, but if you're running it at
 some path into the site, you'll need to specify is using '--prefix=/some_path'.
 
-FILES CHANGED CACHE
--------------------
-
-To speed up the display of the changelog view for large trees,
-loggerhead can be configured to cache the files changes between
-revisions.  Set the 'cachepath' value in the config file.
-
+
+SEARCH
+------
+
+Search is currently supported by using the bzr-search plugin (available
+at: ``https://launchpad.net/bzr-search``
+You need to have the plugin installed and each branch indexed to allow
+searching on branches.
 
 SUPPORT
 -------

=== modified file '__init__.py'
--- __init__.py	2009-06-03 23:21:52 +0000
+++ __init__.py	2009-06-08 23:04:49 +0000
@@ -36,7 +36,7 @@
     import bzrlib
     from bzrlib.api import require_any_api
 
-    require_any_api(bzrlib, [(1, 11, 0), (1, 13, 0), (1, 15, 0)])
+    require_any_api(bzrlib, [(1, 13, 0), (1, 15, 0)])
 
     # NB: Normally plugins should lazily load almost everything, but this
     # seems reasonable to have in-line here: bzrlib.commands and options are

=== modified file 'loggerhead/__init__.py'
--- loggerhead/__init__.py	2009-02-10 21:11:43 +0000
+++ loggerhead/__init__.py	2009-05-29 13:39:28 +0000
@@ -1,3 +1,6 @@
+#
+# Copyright (C) 2008, 2009 Canonical Ltd.
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -20,7 +23,7 @@
 import pkg_resources
 
 __version__ = '1.10'
-required_bzrlib = (1, 6)
+required_bzrlib = (1, 13)
 
 pkg_resources.get_distribution('Paste>=1.6')
 try:

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2009-05-27 16:21:06 +0000
+++ loggerhead/apps/branch.py	2009-05-28 08:17:40 +0000
@@ -1,3 +1,19 @@
+# Copyright (C) 2008, 2009 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
 """The WSGI application for serving a Bazaar branch."""
 
 import logging
@@ -113,6 +129,10 @@
         return self.branch.get_config().get_user_option('public_branch')
 
     def app(self, environ, start_response):
+        # Check again if the branch is blocked from being served, this is
+        # mostly for tests. It's already checked in apps/transport.py
+        if self.branch.get_config().get_user_option('http_serve') == 'False':
+            raise httpexceptions.HTTPNotFound()
         self._url_base = environ['SCRIPT_NAME']
         self._static_url_base = environ.get('loggerhead.static.url')
         if self._static_url_base is None:

=== modified file 'loggerhead/apps/transport.py'
--- loggerhead/apps/transport.py	2009-06-17 22:30:58 +0000
+++ loggerhead/apps/transport.py	2009-06-17 22:33:55 +0000
@@ -1,6 +1,23 @@
+# Copyright (C) 2008, 2009 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
 """Serve branches at urls that mimic a transport's file system layout."""
 
 from bzrlib import branch, errors, lru_cache, urlutils
+from bzrlib.bzrdir import BzrDir
 from bzrlib.transport.http import wsgi
 
 from paste.request import path_info_pop
@@ -64,7 +81,10 @@
                 raise httpexceptions.HTTPNotFound()
             return self.app_for_non_branch(environ)(environ, start_response)
         else:
-            return self.app_for_branch(b)(environ, start_response)
+            if b.get_config().get_user_option('http_serve') == 'False':
+                raise httpexceptions.HTTPNotFound()
+            else:
+                return self.app_for_branch(b)(environ, start_response)
 
 
 class BranchesFromTransportRoot(object):
@@ -76,6 +96,29 @@
         self.smart_server_app = wsgi.RelpathSetter(wsgi_app, '', 'PATH_INFO')
         self._config = config
 
+    def get_local_path(self):
+        """Raise exception if it's not a local path, otherwise return it"""
+
+        # TODO: Use something here that uses the transport API 
+        # rather than relying on the local filesystem API.
+        try:
+            path = urlutils.local_path_from_url(self.transport.base)
+        except errors.InvalidURL:
+            raise httpexceptions.HTTPNotFound()
+        else:
+            return path
+
+    def check_is_a_branch(self, path_info):
+        """Check if it's a branch, and that it's allowed to be shown"""
+        try:
+            bzrdir = BzrDir.open_containing_from_transport(
+                       self.transport.clone(path_info))[0]
+            branch = bzrdir.open_branch()
+            if branch.get_config().get_user_option('http_serve') == 'False':
+                raise httpexceptions.HTTPNotFound()
+        except errors.NotBranchError:
+            return
+
     def __call__(self, environ, start_response):
         environ['loggerhead.static.url'] = environ['SCRIPT_NAME']
         if environ['PATH_INFO'].startswith('/static/'):
@@ -87,15 +130,10 @@
         elif environ['PATH_INFO'].endswith("/.bzr/smart"):
             return self.smart_server_app(environ, start_response)
         elif '/.bzr/' in environ['PATH_INFO']:
-            # TODO: Use something here that uses the transport API 
-            # rather than relying on the local filesystem API.
-            try:
-                path = urlutils.local_path_from_url(self.transport.base)
-            except errors.InvalidURL:
-                raise httpexceptions.HTTPNotFound()
-            else:
-                app = urlparser.make_static(None, path)
-                return app(environ, start_response)
+            self.check_is_a_branch(environ['PATH_INFO'])
+            path = self.get_local_path()
+            app = urlparser.make_static(None, path)
+            return app(environ, start_response)
         else:
             return BranchesFromTransportServer(
                 self.transport, self)(environ, start_response)

=== modified file 'loggerhead/controllers/atom_ui.py'
--- loggerhead/controllers/atom_ui.py	2008-12-05 18:52:44 +0000
+++ loggerhead/controllers/atom_ui.py	2009-06-06 09:09:55 +0000
@@ -35,6 +35,6 @@
         headers['Content-Type'] = 'application/atom+xml'
         return {
             'changes': entries,
-            'updated': entries[0].date.isoformat() + 'Z',
+            'updated': entries[0].utc_date.isoformat(),
             'history': self._history,
         }

=== modified file 'loggerhead/controllers/changelog_ui.py'
--- loggerhead/controllers/changelog_ui.py	2009-03-17 22:38:57 +0000
+++ loggerhead/controllers/changelog_ui.py	2009-05-29 13:39:28 +0000
@@ -1,4 +1,5 @@
 #
+# Copyright (C) 2008, 2009 Canonical Ltd.
 # Copyright (C) 2006  Robey Pointer <robey@lag.net>
 # Copyright (C) 2006  Goffredo Baroncelli <kreijack@inwind.it>
 #

=== modified file 'loggerhead/controllers/directory_ui.py'
--- loggerhead/controllers/directory_ui.py	2009-05-28 13:56:43 +0000
+++ loggerhead/controllers/directory_ui.py	2009-06-02 13:39:33 +0000
@@ -72,6 +72,8 @@
         for d in listing:
             try:
                 b = branch.Branch.open_from_transport(self.transport.clone(d))
+                if b.get_config().get_user_option('http_serve') == 'False':
+                    continue
             except:
                 try:
                     if not stat.S_ISDIR(self.transport.stat(d).st_mode):

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2009-05-28 22:48:45 +0000
+++ loggerhead/history.py	2009-06-09 03:41:07 +0000
@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2008  Canonical Ltd.
+# Copyright (C) 2008, 2009 Canonical Ltd.
 #                     (Authored by Martin Albisetti <argentina@gmail.com>)
 # Copyright (C) 2006  Robey Pointer <robey@lag.net>
 # Copyright (C) 2006  Goffredo Baroncelli <kreijack@inwind.it>
@@ -108,9 +108,6 @@
     return path
 
 
-# from bzrlib
-
-
 class _RevListToTimestamps(object):
     """This takes a list of revisions, and allows you to bisect by date"""
 
@@ -342,25 +339,17 @@
     def get_short_revision_history_by_fileid(self, file_id):
         # FIXME: would be awesome if we could get, for a folder, the list of
         # revisions where items within that folder changed.i
-        try:
-            # FIXME: Workaround for bzr versions prior to 1.6b3.
-            # Remove me eventually pretty please  :)
-            w = self._branch.repository.weave_store.get_weave(
-                    file_id, self._branch.repository.get_transaction())
-            w_revids = w.versions()
-            revids = [r for r in self._rev_indices if r in w_revids]
-        except AttributeError:
-            possible_keys = [(file_id, revid) for revid in self._rev_indices]
-            get_parent_map = self._branch.repository.texts.get_parent_map
-            # We chunk the requests as this works better with GraphIndex.
-            # See _filter_revisions_touching_file_id in bzrlib/log.py
-            # for more information.
-            revids = []
-            chunk_size = 1000
-            for start in xrange(0, len(possible_keys), chunk_size):
-                next_keys = possible_keys[start:start + chunk_size]
-                revids += [k[1] for k in get_parent_map(next_keys)]
-            del possible_keys, next_keys
+        possible_keys = [(file_id, revid) for revid in self._rev_indices]
+        get_parent_map = self._branch.repository.texts.get_parent_map
+        # We chunk the requests as this works better with GraphIndex.
+        # See _filter_revisions_touching_file_id in bzrlib/log.py
+        # for more information.
+        revids = []
+        chunk_size = 1000
+        for start in xrange(0, len(possible_keys), chunk_size):
+            next_keys = possible_keys[start:start + chunk_size]
+            revids += [k[1] for k in get_parent_map(next_keys)]
+        del possible_keys, next_keys
         return revids
 
     def get_revision_history_since(self, revid_list, date):
@@ -660,8 +649,6 @@
         Given a bzrlib Revision, return a processed "change" for use in
         templates.
         """
-        commit_time = datetime.datetime.fromtimestamp(revision.timestamp)
-
         parents = [util.Container(revid=r,
                    revno=self.get_revno(r)) for r in revision.parent_ids]
 
@@ -674,7 +661,8 @@
 
         entry = {
             'revid': revision.revision_id,
-            'date': commit_time,
+            'date': datetime.datetime.fromtimestamp(revision.timestamp),
+            'utc_date': datetime.datetime.utcfromtimestamp(revision.timestamp),
             'authors': authors,
             'branch_nick': revision.properties.get('branch-nick', None),
             'short_comment': short_message,

=== modified file 'loggerhead/templates/atom.pt'
--- loggerhead/templates/atom.pt	2009-03-06 09:57:54 +0000
+++ loggerhead/templates/atom.pt	2009-06-06 12:23:11 +0000
@@ -3,17 +3,19 @@
   <title>
     bazaar changes for <tal:branch-name content="branch/friendly_name">branch name</tal:branch-name>
   </title>
-  <updated tal:content="updated">${updated}</updated>
+  <updated tal:content="string:${updated}Z">${updated}</updated>
   <id tal:content="python:branch.url(['/atom'])">url</id>
-  <link rel="self" tal:attributes="href python:branch.url([''])" />
+  <link rel="self" type="application/atom+xml" tal:attributes="href python:branch.url(['/atom'])" />
+  <link rel="alternate" type="text/html" tal:attributes="href python:branch.url(['/changes'])" />
 
   <entry tal:repeat="entry changes">
-    <title tal:content="string: ${entry/revno}: ${entry/short_comment}">
+    <title tal:content="string:${entry/revno}: ${entry/short_comment}">
       ${entry/revno}: ${entry/short_comment}
     </title>
-    <updated tal:content="entry/date/isoformat">
-    Z
+    <updated tal:content="string:${entry/utc_date/isoformat}Z">
+      updated
     </updated>
+    <!-- TODO: The feed validator will generate warnings because this is URL-encoded -->
     <id tal:content="python:branch.url(['/revision', entry.revno])">
       ID
     </id>
@@ -25,7 +27,7 @@
     <content type="text" tal:content="entry/comment">
       comment
     </content>
-    <link rel="alternate"
+    <link rel="alternate" type="text/html"
           tal:attributes="href python:branch.url(['/revision', entry.revno])" />
   </entry>
 </feed>

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2009-05-29 13:25:59 +0000
+++ loggerhead/tests/test_simple.py	2009-06-08 23:02:49 +0000
@@ -1,3 +1,20 @@
+# Copyright (C) 2008, 2009 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
 import cgi
 import logging
 
@@ -104,6 +121,7 @@
 
 
 class TestEmptyBranch(BasicTests):
+    """Test that an empty branch doesn't break"""
 
     def setUp(self):
         BasicTests.setUp(self)
@@ -119,6 +137,26 @@
         res = app.get('/files')
         res.mustcontain('No revisions!')
 
+
+class TestHiddenBranch(BasicTests):
+    """
+    Test that hidden branches aren't shown
+    FIXME: not tested that it doesn't show up on listings
+    """
+
+    def setUp(self):
+        BasicTests.setUp(self)
+        self.createBranch()
+        locations = config.locations_config_filename()
+        config.ensure_config_dir_exists()
+        open(locations, 'wb').write('[%s]\nhttp_serve = False'
+                                    % (self.tree.branch.base,))
+
+    def test_no_access(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/changes', status=404)
+
+
 #class TestGlobalConfig(BasicTests):
 #    """
 #    Test that global config settings are respected
@@ -133,5 +171,3 @@
         #FIXME: Figure out how to test this properly
 #        app = self.setUpLoggerhead()
 #        res = app.get('/changes', status=200)
-
-

=== modified file 'loggerhead/wholehistory.py'
--- loggerhead/wholehistory.py	2009-05-18 04:17:11 +0000
+++ loggerhead/wholehistory.py	2009-05-29 13:39:28 +0000
@@ -1,4 +1,5 @@
-# Cache the whole history data needed by loggerhead about a branch.
+#
+# Copyright (C) 2008, 2009 Canonical Ltd.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+"""Cache the whole history data needed by loggerhead about a branch."""
 
 import logging
 import time

=== modified file 'serve-branches'
--- serve-branches	2009-06-03 23:21:52 +0000
+++ serve-branches	2009-06-05 01:59:11 +0000
@@ -95,7 +95,6 @@
 
     # setup_logging() #end
 
-    app = TransLogger(app, logger=logger)
     if config.get_option('profile'):
         from loggerhead.middleware.profile import LSProfMiddleware
         app = LSProfMiddleware(app)
@@ -130,6 +129,7 @@
 
     app = HTTPExceptionHandler(app)
     app = ErrorHandlerApp(app)
+    app = TransLogger(app, logger=logger)
 
     if not config.get_option('user_port'):
         port = '8080'

